pub struct PromptFragment { /* private fields */ }Expand description
A source-attributed piece of a model request. Fields are private; the only constructors require attribution at the call site.
ⓘ
use htmlp::runtime::{PromptFragment, Role};
let fragment = PromptFragment::text(Role::User, "untagged");Implementations
Sourceimpl PromptFragment
impl PromptFragment
pub fn new( source: ContentSource, role: Role, content: Vec<ContentBlock>, ) -> Self
pub fn text(source: ContentSource, role: Role, text: impl Into<String>) -> Self
Sourcepub fn checked(
source: ContentSource,
role: Role,
rendered: &RenderedPrompt,
) -> Self
pub fn checked( source: ContentSource, role: Role, rendered: &RenderedPrompt, ) -> Self
Construct a text fragment from immutable, fully checked HTMLP output.
pub fn source(&self) -> &ContentSource
pub fn role(&self) -> Role
pub fn content(&self) -> &[ContentBlock]
pub fn byte_count(&self) -> usize