pub struct SourceEstimate {
pub source: ContentSource,
pub text_bytes: usize,
pub images: u64,
pub tokens: u64,
}Expand description
One source’s heuristic allocation, not provider-reported category usage.
Fields
source: ContentSourcetext_bytes: usizeimages: u64tokens: u64Trait Implementations
Sourceimpl Clone for SourceEstimate
impl Clone for SourceEstimate
Sourcefn clone(&self) -> SourceEstimate
fn clone(&self) -> SourceEstimate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceEstimate
impl Debug for SourceEstimate
Sourceimpl<'de> Deserialize<'de> for SourceEstimate
impl<'de> Deserialize<'de> for SourceEstimate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SourceEstimate
Sourceimpl JsonSchema for SourceEstimate
impl JsonSchema for SourceEstimate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SourceEstimate
impl PartialEq for SourceEstimate
Sourcefn eq(&self, other: &SourceEstimate) -> bool
fn eq(&self, other: &SourceEstimate) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SourceEstimate
impl Serialize for SourceEstimate
impl StructuralPartialEq for SourceEstimate