pub struct Measurement {
pub id: Option<String>,
pub tokens: Option<u64>,
pub limit: Option<u64>,
pub deferred: bool,
pub reason: Option<String>,
}Expand description
Per-element measurement. tokens is None and deferred is true when
unbound variables prevent an exact count. Render to enforce those budgets.
Fields
id: Option<String>tokens: Option<u64>limit: Option<u64>deferred: boolreason: Option<String>Trait Implementations
Sourceimpl Clone for Measurement
impl Clone for Measurement
Sourcefn clone(&self) -> Measurement
fn clone(&self) -> Measurement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Measurement
impl Debug for Measurement
Sourceimpl JsonSchema for Measurement
impl JsonSchema for Measurement
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Measurement
impl RefUnwindSafe for Measurement
impl Send for Measurement
impl Sync for Measurement
impl Unpin for Measurement
impl UnsafeUnpin for Measurement
impl UnwindSafe for Measurement