pub struct SectionOrigin {
pub id: Option<String>,
pub position: Position,
}Expand description
A containing section, including unnamed sections and their source position.
Fields
id: Option<String>position: PositionTrait Implementations
Sourceimpl Clone for SectionOrigin
impl Clone for SectionOrigin
Sourcefn clone(&self) -> SectionOrigin
fn clone(&self) -> SectionOrigin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SectionOrigin
impl Debug for SectionOrigin
impl Eq for SectionOrigin
Sourceimpl PartialEq for SectionOrigin
impl PartialEq for SectionOrigin
Sourcefn eq(&self, other: &SectionOrigin) -> bool
fn eq(&self, other: &SectionOrigin) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SectionOrigin
impl Serialize for SectionOrigin
impl StructuralPartialEq for SectionOrigin