pub struct TextMeasurement {
pub tokenizer: String,
pub tokens: u64,
}Expand description
A tokenizer-specific count of a complete rendered document, excluding provider message framing. Distinct from a runtime request estimate.
Fields
tokenizer: Stringtokens: u64Trait Implementations
Sourceimpl Clone for TextMeasurement
impl Clone for TextMeasurement
Sourcefn clone(&self) -> TextMeasurement
fn clone(&self) -> TextMeasurement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextMeasurement
impl Debug for TextMeasurement
impl Eq for TextMeasurement
Sourceimpl PartialEq for TextMeasurement
impl PartialEq for TextMeasurement
Sourcefn eq(&self, other: &TextMeasurement) -> bool
fn eq(&self, other: &TextMeasurement) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TextMeasurement
impl Serialize for TextMeasurement
impl StructuralPartialEq for TextMeasurement