pub struct Variable {
pub id: String,
pub position: Position,
}Expand description
A named string slot: {{question}}. Variables have no limits.
ⓘ
use htmlp::{Variable, Position};
let slot = Variable { id: "question".into(), max_tokens: 100, position: Position::default() };Fields
id: Stringposition: PositionTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Variable
impl<'de> Deserialize<'de> for Variable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Variable
Sourceimpl JsonSchema for Variable
impl JsonSchema for Variable
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Variable